
%
% The dimension of the problem. Here: 20 cities.
% Try other dimensions, if you want.
% 

DIM = 20;


%
% Create a random initial city sequence.
%

problem.INITIAL_SOLUTION = 1 : DIM;
for i = 1 : 10 * DIM
	problem.INITIAL_SOLUTION = RandomizeCitySequence(problem.INITIAL_SOLUTION);
	drawnow('update');
    %fflush(stdout);
end


%
% Create a circular city. Here, the optimal round trip is actually a circle.
%

problem.CITIES = zeros(DIM, 2);
for i = 1 : DIM
	phi = (i - 1) * (2 * 3.1416) / DIM;
	x   = cos(phi);
	y   = sin(phi);
	problem.CITIES(i, :) = [x, y];
end


%
% Plot the initial solution.
%

figure(1);
newplot();
DrawSalesman(problem.INITIAL_SOLUTION, problem);
title ('Initial solution');
drawnow();


%
% Run the optimization. Feel free to change the parameters.
%

problem.RANDOMIZE = @RandomizeCitySequence;
problem.OBJECTIVE_FUNCTION = @EvaluateCitySequence;
problem.MAX_ITERATIONS = 1000;
problem.C = 1.0;

[solutions, values] = SimulatedAnnealing(problem);


%
% Plot the final result. (Note that better solutions 
% may have been found during the iterations!)
%

figure(2)
newplot();
DrawSalesman(solutions(size(solutions,1), :), problem);
title('Final Solution');
drawnow();

figure(3)
newplot();
plot(values);
title('Objective function values over iterations');
